pyjabber.stanzas.error package
==============================

Submodules
----------

pyjabber.stanzas.error.StanzaError module
-----------------------------------------

.. automodule:: pyjabber.stanzas.error.StanzaError
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.stanzas.error
   :members:
   :undoc-members:
   :show-inheritance:
